package com.xinelu.manage.service.residentinfo.impl;

import com.xinelu.manage.domain.residentinfo.ResidentInfo;
import com.xinelu.manage.mapper.residentinfo.ResidentInfoMapper;
import com.xinelu.manage.service.residentinfo.IResidentInfoService;
import java.time.LocalDateTime;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;

/**
 * 居民信息Service业务层处理
 *
 * @author haown
 * @date 2024-03-27
 */
@Service public class ResidentInfoServiceImpl implements IResidentInfoService {
	@Resource private ResidentInfoMapper residentInfoMapper;

	/**
	 * 查询居民信息
	 *
	 * @param id 居民信息主键
	 * @return 居民信息
	 */
	@Override public ResidentInfo selectResidentInfoById(Long id) {
		return residentInfoMapper.selectResidentInfoById(id);
	}

	/**
	 * 查询居民信息列表
	 *
	 * @param residentInfo 居民信息
	 * @return 居民信息
	 */
	@Override public List<ResidentInfo> selectResidentInfoList(ResidentInfo residentInfo) {
		return residentInfoMapper.selectResidentInfoList(residentInfo);
	}

	/**
	 * 新增居民信息
	 *
	 * @param residentInfo 居民信息
	 * @return 结果
	 */
	@Override public int insertResidentInfo(ResidentInfo residentInfo) {
		residentInfo.setCreateTime(LocalDateTime.now());
		return residentInfoMapper.insertResidentInfo(residentInfo);
	}

	/**
	 * 修改居民信息
	 *
	 * @param residentInfo 居民信息
	 * @return 结果
	 */
	@Override public int updateResidentInfo(ResidentInfo residentInfo) {
		residentInfo.setUpdateTime(LocalDateTime.now());
		return residentInfoMapper.updateResidentInfo(residentInfo);
	}

	/**
	 * 批量删除居民信息
	 *
	 * @param ids 需要删除的居民信息主键
	 * @return 结果
	 */
	@Override public int deleteResidentInfoByIds(Long[] ids) {
		return residentInfoMapper.deleteResidentInfoByIds(ids);
	}

	/**
	 * 删除居民信息信息
	 *
	 * @param id 居民信息主键
	 * @return 结果
	 */
	@Override public int deleteResidentInfoById(Long id) {
		return residentInfoMapper.deleteResidentInfoById(id);
	}
}
